summaryrefslogtreecommitdiffstatshomepage
diff options
context:
space:
mode:
author angelosa <salese_corp_ltd@email.it>2018-01-09 17:45:55 +0100
committer angelosa <salese_corp_ltd@email.it>2018-01-09 17:50:07 +0100
commit78b033a14bd4b5a1d4384af8e5965230a4145590 (patch)
tree3cb3db60a30b32e273238343e69b0af591496579
parent53f19de81d80247e418d88e491954f7b8e0e2f88 (diff)
bulk replace zipnames 47pie / suchipi -> suchie* (nw)
-rw-r--r--src/mame/drivers/jalmah.cpp30
-rw-r--r--src/mame/drivers/ms32.cpp20
-rw-r--r--src/mame/includes/ms32.h2
-rw-r--r--src/mame/mame.lst6
-rw-r--r--src/mame/video/ms32.cpp6
5 files changed, 32 insertions, 32 deletions
diff --git a/src/mame/drivers/jalmah.cpp b/src/mame/drivers/jalmah.cpp
index 45e055c1ec5..6fc9aad2a42 100644
--- a/src/mame/drivers/jalmah.cpp
+++ b/src/mame/drivers/jalmah.cpp
@@ -22,7 +22,7 @@ Notes(general):
TODO:
-kakumei2: unemulated RNG;
--Back layer pens looks ugly in some circumstances (i.e. suchipi when you win, mjzoomin when coined up),
+-Back layer pens looks ugly in some circumstances (i.e. suchiesp when you win, mjzoomin when coined up),
static or controlled by something else?
-daireika: the ranking screen on the original pcb shows some hearts instead of the "0".
Some investigation indicates that the game reads area "fe100" onwards for these to be filled.
@@ -33,7 +33,7 @@ TODO:
-There could be timing issues caused by MCU simulation at $80004;
-Fix the sound banking, protection-related for the first version of the MCU
(should be somewhere on the work ram/shared ram)
--suchipi: I need a side-by-side to understand if the PAL shuffling is correct with the OKI bgm rom.
+-suchiesp: I need a side-by-side to understand if the PAL shuffling is correct with the OKI bgm rom.
-urashima: might use three/four layers instead of two.It can be checked when you win
a match in particular circumstances because there's a write in the 94000-9bfff region;
-Massive clean-ups needed for the MCU snippet programs and the input-ports, also check if
@@ -58,7 +58,7 @@ Notes (1st MCU ver.):
============================================================================================
Debug cheats:
--(suchipi)
+-(suchiesp)
*
$fe87e: bonus timer,used as a count-down.
*
@@ -93,7 +93,7 @@ lev 5 : 0x74 : 0000 09c4 - "write to Text RAM" (?)
lev 6 : 0x78 : 0000 09ce - "write to Text RAM" (?)
lev 7 : 0x7c : 0000 09d8 - "write to Text RAM" (?)
-kakumei/kakumei2/suchipi 68k irq table vectors
+kakumei/kakumei2/suchiesp 68k irq table vectors
lev 1 : 0x64 : 0000 0506 - rte
lev 2 : 0x68 : 0000 050a - vblank
lev 3 : 0x6c : 0000 051c - rte
@@ -196,8 +196,8 @@ public:
DECLARE_READ16_MEMBER(mjzoomin_mcu_r);
DECLARE_WRITE16_MEMBER(mjzoomin_mcu_w);
DECLARE_READ16_MEMBER(kakumei_mcu_r);
- DECLARE_READ16_MEMBER(suchipi_mcu_r);
- DECLARE_DRIVER_INIT(suchipi);
+ DECLARE_READ16_MEMBER(suchiesp_mcu_r);
+ DECLARE_DRIVER_INIT(suchiesp);
DECLARE_DRIVER_INIT(kakumei);
DECLARE_DRIVER_INIT(urashima);
DECLARE_DRIVER_INIT(kakumei2);
@@ -583,7 +583,7 @@ WRITE16_MEMBER(jalmah_state::sc2_vram_w)
WRITE16_MEMBER(jalmah_state::jalmah_tilebank_w)
{
/*
- xxxx ---- fg bank (used by suchipi)
+ xxxx ---- fg bank (used by suchiesp)
---- xxxx Priority number (trusted,see mjzoomin)
*/
//popmessage("Write to tilebank %02x",data);
@@ -713,7 +713,7 @@ take it seriously...):
0x13 = mjzoomin
0x21 = kakumei
0x22 = kakumei2
-0x23 = suchipi
+0x23 = suchiesp
xxxx ---- MCU program revision
---- xxxx MCU program number assignment for each game.
@@ -1344,7 +1344,7 @@ static INPUT_PORTS_START( kakumei2 )
PORT_DIPSETTING( 0x0000, DEF_STR( On ) )
INPUT_PORTS_END
-static INPUT_PORTS_START( suchipi )
+static INPUT_PORTS_START( suchiesp )
PORT_INCLUDE( kakumei2 )
PORT_MODIFY("DSW")
@@ -1706,7 +1706,7 @@ NEC D65012GF303 9050KX016 (80pin QFP) x4
*/
-ROM_START( suchipi )
+ROM_START( suchiesp )
ROM_REGION( 0x80000, "maincpu", 0 ) /* 68000 Code */
ROM_LOAD16_BYTE( "1.bin", 0x00001, 0x40000, CRC(e37cc745) SHA1(73b3314d27a0332068e0d2bbc08d7401e371da1b) )
ROM_LOAD16_BYTE( "2.bin", 0x00000, 0x40000, CRC(42ecf88a) SHA1(7bb85470bc9f94c867646afeb91c4730599ea299) )
@@ -2307,7 +2307,7 @@ WRITE16_MEMBER(jalmah_state::mjzoomin_mcu_w)
jm_mcu_code[0x0008/2] = 0x4e75;//rts
/*******************************************************
2nd M68k code uploaded by the MCU (Sound read/write)
- (Note:copied from suchipi,check here the sound banking)
+ (Note:copied from suchiesp,check here the sound banking)
*******************************************************/
jm_shared_ram[0x0020/2] = 0x4ef9;
jm_shared_ram[0x0022/2] = 0x0010;
@@ -2414,7 +2414,7 @@ READ16_MEMBER(jalmah_state::kakumei_mcu_r)
return res;
}
-READ16_MEMBER(jalmah_state::suchipi_mcu_r)
+READ16_MEMBER(jalmah_state::suchiesp_mcu_r)
{
static const int resp[] = { 0x8a, 0xd8, 0x00,
0x3c, 0x7c, 0x00,
@@ -2472,9 +2472,9 @@ DRIVER_INIT_MEMBER(jalmah_state,kakumei2)
m_mcu_prg = 0x22;
}
-DRIVER_INIT_MEMBER(jalmah_state,suchipi)
+DRIVER_INIT_MEMBER(jalmah_state,suchiesp)
{
- m_maincpu->space(AS_PROGRAM).install_read_handler(0x80004, 0x80005, read16_delegate(FUNC(jalmah_state::suchipi_mcu_r), this));
+ m_maincpu->space(AS_PROGRAM).install_read_handler(0x80004, 0x80005, read16_delegate(FUNC(jalmah_state::suchiesp_mcu_r), this));
m_mcu_prg = 0x23;
}
@@ -2486,4 +2486,4 @@ GAME( 1990, mjzoomin, 0, jalmah, mjzoomin, jalmah_state, mjzoomin, ROT0, "J
/*Second version of the MCU*/
GAME( 1990, kakumei, 0, jalmah, kakumei, jalmah_state, kakumei, ROT0, "Jaleco", "Mahjong Kakumei (Japan)", MACHINE_IMPERFECT_GRAPHICS )
GAME( 1992, kakumei2, 0, jalmah, kakumei2, jalmah_state, kakumei2, ROT0, "Jaleco", "Mahjong Kakumei 2 - Princess League (Japan)", MACHINE_IMPERFECT_GRAPHICS | MACHINE_UNEMULATED_PROTECTION )
-GAME( 1993, suchipi, 0, jalmah, suchipi, jalmah_state, suchipi, ROT0, "Jaleco", "Idol Janshi Suchie-Pai Special (Japan)", MACHINE_IMPERFECT_GRAPHICS )
+GAME( 1993, suchiesp, 0, jalmah, suchiesp, jalmah_state, suchiesp, ROT0, "Jaleco", "Idol Janshi Suchie-Pai Special (Japan)", MACHINE_IMPERFECT_GRAPHICS )
diff --git a/src/mame/drivers/ms32.cpp b/src/mame/drivers/ms32.cpp
index 681dbfcf4a5..588e80d2576 100644
--- a/src/mame/drivers/ms32.cpp
+++ b/src/mame/drivers/ms32.cpp
@@ -149,7 +149,7 @@ Second Earth Gratia (92047-01 version) (gratia)
*Second Earth Gratia (91022-10 version) (gratiaa) (redump needed)
F-1 Super Battle (f1superb)
-Idol Janshi Su-Chi-Pi 2 (47pie2)
+Idol Janshi Su-Chi-Pi 2 (suchie2)
Ryuusei Janshi Kirara Star (kirarast)
Mahjong Angel Kiss
Vs. Janshi Brand New Stars
@@ -1095,7 +1095,7 @@ static INPUT_PORTS_START( kirarast ) // player 1 inputs done? others?
PORT_DIPSETTING( 0x00000020, DEF_STR( Hardest ) )
INPUT_PORTS_END
-static INPUT_PORTS_START( 47pie2 ) // player 1 inputs done? others?
+static INPUT_PORTS_START( suchie2 ) // player 1 inputs done? others?
PORT_INCLUDE( kirarast )
PORT_MODIFY("INPUTS")
@@ -1489,7 +1489,7 @@ ROM_START( bbbxing )
ROM_LOAD( "91022-01.ic83", 0x00000, 0x00001, NO_DUMP ) /* AMI 18CV8-15. */
ROM_END
-ROM_START( 47pie2 )
+ROM_START( suchie2 )
ROM_REGION( 0x200000, "maincpu", 0 ) /* V70 code */
ROM_LOAD32_BYTE( "93166-26.v11", 0x000003, 0x80000, CRC(e4e62134) SHA1(224b3e8dba56009bf2af6eceb7495e60302a6360) )
ROM_LOAD32_BYTE( "93166-27.v11", 0x000002, 0x80000, CRC(7bd00919) SHA1(60565b5e1da5fee00ac4a7fb1202d7150dab49ee) )
@@ -1526,7 +1526,7 @@ ROM_START( 47pie2 )
ROM_LOAD( "91022-01.ic83", 0x00000, 0x00001, NO_DUMP ) /* AMI 18CV8-15. */
ROM_END
-ROM_START( 47pie2o )
+ROM_START( suchie2o )
ROM_REGION( 0x200000, "maincpu", 0 ) /* V70 code */
ROM_LOAD32_BYTE( "93166-26.v10", 0x000003, 0x80000, CRC(21dc94dd) SHA1(faf2eea891cb061d5df47ef31d9538feb0c1233c) )
ROM_LOAD32_BYTE( "93166-27.v10", 0x000002, 0x80000, CRC(5bf18a7d) SHA1(70869dc37e6ad79ce4e85db71a03c5cccf9d732b) )
@@ -2233,7 +2233,7 @@ DRIVER_INIT_MEMBER(ms32_state,ss92047_01)
decrypt_ms32_bg(machine(), 0x24000,0x55, "gfx3");
}
-/* SS92048-01: p47aces, 47pie2, 47pie2o */
+/* SS92048-01: p47aces, suchie2, suchie2o */
DRIVER_INIT_MEMBER(ms32_state,ss92048_01)
{
DRIVER_INIT_CALL(ms32_common);
@@ -2247,7 +2247,7 @@ DRIVER_INIT_MEMBER(ms32_state,kirarast)
DRIVER_INIT_CALL(ss92047_01);
}
-DRIVER_INIT_MEMBER(ms32_state,47pie2)
+DRIVER_INIT_MEMBER(ms32_state,suchie2)
{
DRIVER_INIT_CALL(ss92048_01);
}
@@ -2273,18 +2273,18 @@ DRIVER_INIT_MEMBER(ms32_state,bnstars)
GAME( 1994, hayaosi2, 0, ms32, hayaosi2, ms32_state, ss92046_01, ROT0, "Jaleco", "Hayaoshi Quiz Grand Champion Taikai", MACHINE_IMPERFECT_GRAPHICS | MACHINE_IMPERFECT_SOUND )
GAME( 1994, hayaosi3, 0, ms32, hayaosi3, ms32_state, ss92046_01, ROT0, "Jaleco", "Hayaoshi Quiz Nettou Namahousou", MACHINE_IMPERFECT_GRAPHICS | MACHINE_IMPERFECT_SOUND )
GAME( 1994, bbbxing, 0, ms32, bbbxing, ms32_state, ss92046_01, ROT0, "Jaleco", "Best Bout Boxing", MACHINE_IMPERFECT_GRAPHICS | MACHINE_IMPERFECT_SOUND )
-GAME( 1994, 47pie2, 0, ms32, 47pie2, ms32_state, 47pie2, ROT0, "Jaleco", "Idol Janshi Suchie-Pai II (v1.1)", MACHINE_IMPERFECT_GRAPHICS | MACHINE_IMPERFECT_SOUND | MACHINE_SUPPORTS_SAVE )
-GAME( 1994, 47pie2o, 47pie2, ms32, 47pie2, ms32_state, 47pie2, ROT0, "Jaleco", "Idol Janshi Suchie-Pai II (v1.0)", MACHINE_IMPERFECT_GRAPHICS | MACHINE_IMPERFECT_SOUND | MACHINE_SUPPORTS_SAVE )
+GAME( 1994, suchie2, 0, ms32, suchie2, ms32_state, suchie2, ROT0, "Jaleco", "Idol Janshi Suchie-Pai II (v1.1)", MACHINE_IMPERFECT_GRAPHICS | MACHINE_IMPERFECT_SOUND | MACHINE_SUPPORTS_SAVE )
+GAME( 1994, suchie2o, suchie2, ms32, suchie2, ms32_state, suchie2, ROT0, "Jaleco", "Idol Janshi Suchie-Pai II (v1.0)", MACHINE_IMPERFECT_GRAPHICS | MACHINE_IMPERFECT_SOUND | MACHINE_SUPPORTS_SAVE )
GAME( 1995, desertwr, 0, ms32, desertwr, ms32_state, ss91022_10, ROT270, "Jaleco", "Desert War / Wangan Sensou", MACHINE_IMPERFECT_GRAPHICS | MACHINE_IMPERFECT_SOUND | MACHINE_SUPPORTS_SAVE )
GAME( 1995, gametngk, 0, ms32, gametngk, ms32_state, ss91022_10, ROT270, "Jaleco", "The Game Paradise - Master of Shooting! / Game Tengoku - The Game Paradise", MACHINE_IMPERFECT_GRAPHICS | MACHINE_IMPERFECT_SOUND | MACHINE_SUPPORTS_SAVE )
GAME( 1995, tetrisp, 0, ms32, tetrisp, ms32_state, ss92046_01, ROT0, "Jaleco / BPS", "Tetris Plus", MACHINE_IMPERFECT_GRAPHICS | MACHINE_IMPERFECT_SOUND | MACHINE_SUPPORTS_SAVE )
GAME( 1995, p47aces, 0, ms32, p47aces, ms32_state, ss92048_01, ROT0, "Jaleco", "P-47 Aces", MACHINE_IMPERFECT_GRAPHICS | MACHINE_IMPERFECT_SOUND | MACHINE_SUPPORTS_SAVE )
-GAME( 1995, akiss, 0, ms32, 47pie2, ms32_state, kirarast, ROT0, "Jaleco", "Mahjong Angel Kiss", MACHINE_IMPERFECT_GRAPHICS | MACHINE_IMPERFECT_SOUND | MACHINE_SUPPORTS_SAVE )
+GAME( 1995, akiss, 0, ms32, suchie2, ms32_state, kirarast, ROT0, "Jaleco", "Mahjong Angel Kiss", MACHINE_IMPERFECT_GRAPHICS | MACHINE_IMPERFECT_SOUND | MACHINE_SUPPORTS_SAVE )
GAME( 1996, gratia, 0, ms32, gratia, ms32_state, ss92047_01, ROT0, "Jaleco", "Gratia - Second Earth (92047-01 version)", MACHINE_IMPERFECT_GRAPHICS | MACHINE_IMPERFECT_SOUND | MACHINE_SUPPORTS_SAVE )
GAME( 1996, gratiaa, gratia, ms32, gratia, ms32_state, ss91022_10, ROT0, "Jaleco", "Gratia - Second Earth (91022-10 version)", MACHINE_IMPERFECT_GRAPHICS | MACHINE_IMPERFECT_SOUND | MACHINE_SUPPORTS_SAVE )
GAME( 1996, kirarast, 0, ms32, kirarast, ms32_state, kirarast, ROT0, "Jaleco", "Ryuusei Janshi Kirara Star", MACHINE_IMPERFECT_GRAPHICS | MACHINE_IMPERFECT_SOUND | MACHINE_SUPPORTS_SAVE )
GAME( 1997, tp2m32, tetrisp2, ms32, tp2m32, ms32_state, ss91022_10, ROT0, "Jaleco", "Tetris Plus 2 (MegaSystem 32 Version)", MACHINE_IMPERFECT_GRAPHICS | MACHINE_IMPERFECT_SOUND | MACHINE_SUPPORTS_SAVE )
-GAME( 1997, bnstars, bnstars1, ms32, 47pie2, ms32_state, bnstars, ROT0, "Jaleco", "Vs. Janshi Brandnew Stars (MegaSystem32 Version)", MACHINE_IMPERFECT_GRAPHICS | MACHINE_IMPERFECT_SOUND | MACHINE_SUPPORTS_SAVE )
+GAME( 1997, bnstars, bnstars1, ms32, suchie2, ms32_state, bnstars, ROT0, "Jaleco", "Vs. Janshi Brandnew Stars (MegaSystem32 Version)", MACHINE_IMPERFECT_GRAPHICS | MACHINE_IMPERFECT_SOUND | MACHINE_SUPPORTS_SAVE )
GAME( 1996, wpksocv2, 0, ms32, wpksocv2, ms32_state, ss92046_01, ROT0, "Jaleco", "World PK Soccer V2 (ver 1.1)", MACHINE_IMPERFECT_GRAPHICS | MACHINE_IMPERFECT_SOUND | MACHINE_SUPPORTS_SAVE )
diff --git a/src/mame/includes/ms32.h b/src/mame/includes/ms32.h
index cd6c54ec1a7..a70eac6589e 100644
--- a/src/mame/includes/ms32.h
+++ b/src/mame/includes/ms32.h
@@ -97,7 +97,7 @@ public:
DECLARE_DRIVER_INIT(ss92047_01);
DECLARE_DRIVER_INIT(ss91022_10);
DECLARE_DRIVER_INIT(kirarast);
- DECLARE_DRIVER_INIT(47pie2);
+ DECLARE_DRIVER_INIT(suchie2);
DECLARE_DRIVER_INIT(ss92048_01);
DECLARE_DRIVER_INIT(bnstars);
DECLARE_DRIVER_INIT(f1superb);
diff --git a/src/mame/mame.lst b/src/mame/mame.lst
index 21b637612d1..426529d72fb 100644
--- a/src/mame/mame.lst
+++ b/src/mame/mame.lst
@@ -15660,7 +15660,7 @@ daireika // (c) 1989 Jaleco/NMK
kakumei // (c) 1990
kakumei2 // (c) 1992
mjzoomin // (c) 1990
-suchipi // (c) 1993
+suchiesp // (c) 1993
urashima // UPL-89052
@source:jangou.cpp
@@ -27859,8 +27859,8 @@ ms0515 //
ms6102 //
@source:ms32.cpp
-47pie2 // (c) 1994
-47pie2o // (c) 1994
+suchie2 // (c) 1994
+suchie2o // (c) 1994
akiss // (c) 1995
bbbxing // (c) 1994
bnstars // (c) 1997
diff --git a/src/mame/video/ms32.cpp b/src/mame/video/ms32.cpp
index 08aac4de5fc..e9ccaaaa417 100644
--- a/src/mame/video/ms32.cpp
+++ b/src/mame/video/ms32.cpp
@@ -18,7 +18,7 @@ priority should be given to
#include "includes/ms32.h"
// kirarast, tp2m32, and 47pie2 require the sprites in a different order
/********** Tilemaps **********/
@@ -91,8 +91,8 @@ void ms32_state::video_start()
/* i hate per game patches...how should priority really work? tetrisp2.c ? i can't follow it */
if (!strcmp(machine().system().name,"kirarast")) m_reverse_sprite_order = 0;
if (!strcmp(machine().system().name,"tp2m32")) m_reverse_sprite_order = 0;
- if (!strcmp(machine().system().name,"47pie2")) m_reverse_sprite_order = 0;
- if (!strcmp(machine().system().name,"47pie2o")) m_reverse_sprite_order = 0;
+ if (!strcmp(machine().system().name,"suchie2")) m_reverse_sprite_order = 0;
+ if (!strcmp(machine().system().name,"suchie2o")) m_reverse_sprite_order = 0;
if (!strcmp(machine().system().name,"hayaosi3")) m_reverse_sprite_order = 0;
if (!strcmp(machine().system().name,"bnstars")) m_reverse_sprite_order = 0;
if (!strcmp(machine().system().name,"wpksocv2")) m_reverse_sprite_order = 0;
@@ -18,7 +18,7 @@ priority should be given to
#include "includes/ms32.h"
-// kirarast, tp2m32, and 47pie2 require the sprites in a different order
+// kirarast, tp2m32, and suchie2 require the sprites in a different order
/********** Tilemaps **********/